@@ -4,6 +4,7 @@ var group__misc__types =
       [ "addons", "structecs__build__info__t.html#a7470b69cc140c386908ec8102cfc6e8f", null ],
       [ "compiler", "structecs__build__info__t.html#a8162a3130dd6c6b769e8da3451700d28", null ],
       [ "debug", "structecs__build__info__t.html#af2735a6a8d0994173a3bbcf9b4e1ee9e", null ],
+      [ "flags", "structecs__build__info__t.html#a465a1a862a07a8850c154d911078af64", null ],
       [ "perf_trace", "structecs__build__info__t.html#ac3673cab868e24d52cd699916424dd32", null ],
       [ "sanitize", "structecs__build__info__t.html#aa21677164909e9e5e70f835b9337f18d", null ],
       [ "version", "structecs__build__info__t.html#a7a4ad256819c542324f4a0b0248a2987", null ],
@@ -18,6 +19,7 @@ var group__misc__types =
       [ "clear_count", "structecs__world__info__t.html#a95a15d721f0097f4138905745d57b479", null ],
       [ "cmd", "structecs__world__info__t.html#a764899dca86a9bd5ecac6a01aa89463b", null ],
       [ "component_id_count", "structecs__world__info__t.html#a378acee81e415d7be9749ab13a73af05", null ],
+      [ "creation_time", "structecs__world__info__t.html#ae54f550442cf82b2a99b74e977633171", null ],
       [ "delete_count", "structecs__world__info__t.html#abda93bc5d7bb20903380851b79ac4ea2", null ],
       [ "delta_time", "structecs__world__info__t.html#a064a745a142d7865c93895fafaa57891", null ],
       [ "delta_time_raw", "structecs__world__info__t.html#a423da320e10ad87b102a25bd74368ed0", null ],
@@ -37,16 +39,17 @@ var group__misc__types =
       [ "min_id", "structecs__world__info__t.html#a0a65987b62c3178691a01b471b8f7645", null ],
       [ "modified_count", "structecs__world__info__t.html#aedfc548cb8fc79b8754e6814a3c22bae", null ],
       [ "name_prefix", "structecs__world__info__t.html#af13ccc527262482ab8b3c9edb64d8431", null ],
-      [ "observers_ran_frame", "structecs__world__info__t.html#a6b293969d1ea425bd7a4347ba5b4bcdc", null ],
+      [ "observers_ran_total", "structecs__world__info__t.html#a00d084fb66128a3a5ffb3f75992faff0", null ],
       [ "other_count", "structecs__world__info__t.html#aab783a62bb921e69029de256f3c67d96", null ],
       [ "pair_id_count", "structecs__world__info__t.html#acd8c02366b31f72d77b26e8c6c971aa0", null ],
       [ "pipeline_build_count_total", "structecs__world__info__t.html#a402efe5be309f8c0aa544f5e1b4f3caf", null ],
+      [ "queries_ran_total", "structecs__world__info__t.html#abb99162a325ab3202c905930f1c677de", null ],
       [ "rematch_count_total", "structecs__world__info__t.html#abeff90c0e8f3aeab0e7239e58dae0edc", null ],
       [ "rematch_time_total", "structecs__world__info__t.html#ad00bc59ae9524dab4b717254cb122063", null ],
       [ "remove_count", "structecs__world__info__t.html#affad76fae2aaf5e94d51fc41b73e80f1", null ],
       [ "set_count", "structecs__world__info__t.html#a199919dd6a4c1f72a210b34f2babc7f8", null ],
       [ "system_time_total", "structecs__world__info__t.html#a709766143fc7b96eeb173581ab535115", null ],
-      [ "systems_ran_frame", "structecs__world__info__t.html#a74abc83acdc8b3dab7cde29f40bb354b", null ],
+      [ "systems_ran_total", "structecs__world__info__t.html#a0ca484d9e66a188f8c134e188af1fa01", null ],
       [ "table_count", "structecs__world__info__t.html#a40cbca3ca9140b44cb0f8f15b648bb54", null ],
       [ "table_create_total", "structecs__world__info__t.html#a69a67fda146fcd79f23232f07a32f443", null ],
       [ "table_delete_total", "structecs__world__info__t.html#ab3807b0f99e15a5b51f0fe005faef828", null ],
